import React, { useContext } from 'react';

var PluginStore = /*#__PURE__*/function () {
  function PluginStore() {
    this.functionArray = new Map();
    this.pluginMap = new Map();
  }

  var _proto = PluginStore.prototype;

  _proto.install = function install(key, plugin) {
    this.pluginMap.set(key, plugin);
    plugin.init(this);
    plugin.activate();
  };

  _proto.addFunction = function addFunction(key, fn) {
    this.functionArray.set(key, fn);
  };

  _proto.executeFunction = function executeFunction(key) {
    var fn = this.functionArray.get(key);

    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    return fn.apply(void 0, args);
  };

  return PluginStore;
}();

function createPluginStore() {
  return new PluginStore();
}

var PluginStoreContext = /*#__PURE__*/React.createContext( /*#__PURE__*/new PluginStore());

var PluginProvider = function PluginProvider(_ref) {
  var pluginStore = _ref.pluginStore,
      children = _ref.children;
  var PluginStore = PluginStoreContext;
  return React.createElement(PluginStore.Provider, {
    value: pluginStore
  }, children);
};

function usePluginStore() {
  return useContext(PluginStoreContext);
}

var Renderer = function Renderer(_ref) {
  var placement = _ref.placement;
  var pluginStore = usePluginStore();
  var components = pluginStore.executeFunction('RendererPlugin.getComponentsInPosition', placement);
  return React.createElement(React.Fragment, null, components.map(function (Component) {
    return React.createElement(Component, null);
  }));
};

var RendererPlugin = /*#__PURE__*/function () {
  function RendererPlugin() {
    this.pluginStore = new PluginStore();
    this.componentMap = new Map();
  }

  var _proto = RendererPlugin.prototype;

  _proto.init = function init(pluginStore) {
    this.pluginStore = pluginStore;
  };

  _proto.addToComponentMap = function addToComponentMap(position, component) {
    var array = this.componentMap.get(position);

    if (!array) {
      array = [component];
    }

    this.componentMap.set(position, array);
  };

  _proto.getRendererComponent = function getRendererComponent() {
    return Renderer;
  };

  _proto.getComponentsInPosition = function getComponentsInPosition(position) {
    var componentArray = this.componentMap.get(position);
    if (!componentArray) return [];
    return componentArray;
  };

  _proto.activate = function activate() {
    this.pluginStore.addFunction('RendererPlugin.add', this.addToComponentMap.bind(this));
    this.pluginStore.addFunction('RendererPlugin.getComponentsInPosition', this.getComponentsInPosition.bind(this));
    this.pluginStore.addFunction('RendererPlugin.getRendererComponent', this.getRendererComponent.bind(this));
  };

  _proto.deactivate = function deactivate() {//
  };

  return RendererPlugin;
}();

export { PluginProvider, RendererPlugin, createPluginStore, usePluginStore };
//# sourceMappingURL=react-pluggable.esm.js.map
